package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.common.core.domain.entity.SysUser;

/**
 * 用户 业务层
 * 
 * @author ruoyi
 */
public interface ISysUserService
{
    /**
     * 根据条件分页查询用户列表
     *
     * @param sysUser 用户信息
     * @return 用户信息集合信息
     */
    public List<SysUser> selectUserList(SysUser sysUser);

    /**
     * 根据条件分页查询已分配用户角色列表
     *
     * @param sysUser 用户信息
     * @return 用户信息集合信息
     */
    public List<SysUser> selectAllocatedList(SysUser sysUser);

    /**
     * 根据条件分页查询未分配用户角色列表
     *
     * @param sysUser 用户信息
     * @return 用户信息集合信息
     */
    public List<SysUser> selectUnallocatedList(SysUser sysUser);

    /**
     * 通过用户名查询用户
     *
     * @param username 用户名
     * @return 用户对象信息
     */
    public SysUser selectUserByUserName(String username);

    /**
     * 通过用户ID查询用户
     *
     * @param userId 用户ID
     * @return 用户对象信息
     */
    public SysUser selectUserById(Long userId);

    /**
     * 根据用户ID查询用户所属角色组
     *
     * @param username 用户名
     * @return 结果
     */
    public String selectUserRoleGroup(String username);

    /**
     * 根据用户ID查询用户所属岗位组
     *
     * @param username 用户名
     * @return 结果
     */
    public String selectUserPostGroup(String username);

    /**
     * 校验用户名称是否唯一
     *
     * @param sysUser 用户信息
     * @return 结果
     */
    public boolean checkUserNameUnique(SysUser sysUser);

    /**
     * 校验手机号码是否唯一
     *
     * @param sysUser 用户信息
     * @return 结果
     */
    public boolean checkPhoneUnique(SysUser sysUser);

    /**
     * 校验email是否唯一
     *
     * @param sysUser 用户信息
     * @return 结果
     */
    public boolean checkEmailUnique(SysUser sysUser);

    /**
     * 校验用户是否允许操作
     *
     * @param sysUser 用户信息
     */
    public void checkUserAllowed(SysUser sysUser);

    /**
     * 校验用户是否有数据权限
     *
     * @param userId 用户id
     */
    public void checkUserDataScope(Long userId);

    /**
     * 新增用户信息
     *
     * @param sysUser 用户信息
     * @return 结果
     */
    public int insertUser(SysUser sysUser);

    /**
     * 注册用户信息
     *
     * @param sysUser 用户信息
     * @return 结果
     */
    public boolean registerUser(SysUser sysUser);

    /**
     * 修改用户信息
     *
     * @param sysUser 用户信息
     * @return 结果
     */
    public int updateUser(SysUser sysUser);

    /**
     * 用户授权角色
     *
     * @param userId 用户ID
     * @param roleIds 角色组
     */
    public void insertUserAuth(Long userId, Long[] roleIds);

    /**
     * 修改用户状态
     *
     * @param sysUser 用户信息
     * @return 结果
     */
    public int updateUserStatus(SysUser sysUser);

    /**
     * 修改用户基本信息
     *
     * @param sysUser 用户信息
     * @return 结果
     */
    public int updateUserProfile(SysUser sysUser);

    /**
     * 修改用户头像
     *
     * @param username 用户名
     * @param avatar 头像地址
     * @return 结果
     */
    public boolean updateUserAvatar(String username, String avatar);

    /**
     * 重置用户密码
     *
     * @param sysUser 用户信息
     * @return 结果
     */
    public int resetPwd(SysUser sysUser);

    /**
     * 重置用户密码
     *
     * @param username 用户名
     * @param password 密码
     * @return 结果
     */
    public int resetUserPwd(String username, String password);

    /**
     * 通过用户ID删除用户
     *
     * @param userId 用户ID
     * @return 结果
     */
    public int deleteUserById(Long userId);

    /**
     * 批量删除用户信息
     *
     * @param userIds 需要删除的用户ID
     * @return 结果
     */
    public int deleteUserByIds(Long[] userIds);

    /**
     * 导入用户数据
     *
     * @param userList 用户数据列表
     * @param isUpdateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName 操作用户
     * @return 结果
     */
    public String importUser(List<SysUser> userList, Boolean isUpdateSupport, String operName);
}
